// Program for controlling a four-display led display
// Program for driving a bicycle rear light


#include "LedControl.h"
LedControl lc = LedControl (12,11,10,4); 
int intens = 8; // 0 = low; 8 = high
int val = 0;
int valm = 0;
int blink1 = 0; // indicator used to toggle sound and display
// pin ports
int ind02 = 2; // button 
int ind03 = 3; // button 
int sor06 = 6; // tone output
// Time variables
unsigned long previousMillis = 0;     // stores the start time of a display sequence
const long interval = 5000;           // duration of a sequence display
// pictures to display
byte arrow[] =    // "-<>"
{
   B00011000, 
   B00011000,
   B00011000,
   B00011000,
   B00011000,
   B00011000,
   B00011000,
   B00011000,
   B00011000, 
   B00011000,
   B00111100,
   B01111110,
   B11111111,
   B11100111,
   B11000011,
   B10000001,
   B10000001,
   B11000011,
   B11100111,
   B11111111,
   B01111110,
   B00111100,
   B00011000,
   B00011000,
};
byte blink01[] =    // Blink display 
{
   B00011000, //2
   B01111110,
   B01111110,
   B11111111,
   B11111111,
   B01111110,
   B01111110,
   B00011000,
};

void setup() {
  delay(2000); // Waiting for power stability 
  // initialize four ports as input and one for tone
  pinMode(ind02, INPUT); // left 
  pinMode(ind03, INPUT); // right
  pinMode(sor06, OUTPUT); // tone
  // init and enabling led display
  for (int i = 0; i < 4; i++)  
  {
  lc.shutdown (i,false);
  lc.setIntensity (i,intens);
  }
}

void loop() {
    // read control ports, only one pin (can be/is activated)
    val = digitalRead(ind02)*2; 
    val = val + digitalRead(ind03)*3; 
    if (val != 5) {  // a button is pressed
      unsigned long currentMillis = millis();
      previousMillis = currentMillis;
      valm = val;
    }
    if (valm != 5) { // test if unexpired term
      unsigned long currentMillis = millis();
      if (currentMillis - previousMillis >= interval)
      { valm = 0; }
    }
    // display according to the button used or not
     switch (valm) {
      case 0: // no pin activated
       loopblink();
       break;      
      case 5: // no pin activated
       loopblink();
       break;
      case 2: // button righgt is activated
       loopright2();
       break;
      case 3: // button left is activated
       loopleft2();
       break;    
     }
     blink1 = !blink1;
}

// ============ SUBROUTINES ==============================================
void loopright2() {
   for (int i = 8; i >0 ; i--)  
  {
    if (blink1 == 1) {
       lc.setColumn (0,i-1,arrow[i-1]); 
       lc.setColumn (1,i-1,arrow[i-1]);
       lc.setColumn (2,i-1,arrow[i-1]);
       lc.setColumn (3,i-1,arrow[i+8-1]);
       tone(sor06,200); 
    } else {
       lc.clearDisplay (0);
       lc.clearDisplay (1); 
       lc.clearDisplay (2);
       lc.clearDisplay (3);
       tone(sor06,400); 
    }
  }
  delay(100);
}
void loopleft2() {
   for (int i = 0; i < 8 ; i++)  
  {
    if (blink1 == 1) {
       lc.setColumn (3,i,arrow[i]); 
       lc.setColumn (2,i,arrow[i]);
       lc.setColumn (1,i,arrow[i]);
       lc.setColumn (0,i,arrow[i+16]);
       tone(sor06,800); 
    } else {
       lc.clearDisplay (0); 
       lc.clearDisplay (1); 
       lc.clearDisplay (2);
       lc.clearDisplay (3);
       tone(sor06,1000); 
       }
  }
  delay(100); 
}
void loopblink() {
  lc.clearDisplay (0);
  lc.clearDisplay (3);   
  noTone(sor06); 
  for (int l = 0; l < 8; l++)  
  {
    if (blink1 == 1) {
       lc.clearDisplay (1); 
       lc.setRow (2,l,blink01[l]);
    } else {
       lc.setRow (1,l,blink01[l]); // Set second display
       lc.clearDisplay (2); 
    }
  }
  delay(300);
  }
